@@ -21,7 +21,7 @@
 #include "../main.h"
 #include "geocoder.h"
 
-char* cloudmade_prepare_url(char* encodedQuery);
+char* cloudmade_prepare_url(void* encodedQuery);
 void cloudmade_parse_response(char* response);
 
 #endif /* CLOUDMADE_GEOCODER_H_ */
