@@ -15,8 +15,8 @@
 #ifndef NAVIGATION_H_
 #define NAVIGATION_H_
 
-#include "../tileengine.h"
-#include "../geometry.h"
+#include "../tile_engine/tileengine.h"
+#include "../display/geometry.h"
 
 void updateNavigation();
 
