@@ -24,7 +24,7 @@
 #include "../main.h"
 #include "router.h"
 
-char* googleMapsRouterPrepareUrl(RoutingQuery* encodedQuery);
+char* googleMapsRouterPrepareUrl(void* encodedQuery);
 void googleMapsRouterParseResponse(char* response);
 
 #endif /* GOOGLE_MAPS_ROUTER_H_ */
