@@ -16,9 +16,9 @@
 #define ROUTER_H_
 
 #include "../main.h"
-#include "../network.h"
-#include "../tileengine.h"
-#include "../unicode2ascii.h"
+#include "../io/network.h"
+#include "../tile_engine/tileengine.h"
+#include "../display/unicode2ascii.h"
 
 #include "google_maps_router.h"
 #include "cloudmade_router.h"
